Crate fmtparse

Crate fmtparse 

Parse format!-like strings. This is mostly useful if you want to write a proc macro and want to implement format!-like functionality without relying on the original macro.

See https://github.com/CombiRWTH/graph-visualiser-website/blob/6dcce28567d08bb73d4b2bd7533bf246291f3a76/rust/algorithm/impl/src/lib.rs#L203-L223 for an example usage of this crate.

Enums

Align
Padding
Param
A parameter to an option. Can be either a constant or dependent on a variable.
Style
Token
VarName
A variable name. This can be one of these 3 cases:

Functions

parse
Parse a format string. This should mimic the behaviour of Rust. All deviations (both inputs accepted by Rust but not this function and vice versa) are considered bugs.
parse_relaxed
Parse a format string with relaxed idents. Only the initial identifier of a variable is relaxed,