pub fn parse_relaxed(input: &str) -> ParseResult<Vec<Token>, EmptyErr>Expand description
Parse a format string with relaxed idents. Only the initial identifier of a variable is relaxed,
A relaxed identifier doesn’t start with a numeric character and contains any characters that are
- not control chars
- not a whitespace
- not a colon (
:) - no braces (
{or})